# 0.2.0

- Add `--version` flag to CLI.
- Remove pre-existing figure files with `plot` commands.
- Write docs for the CLI commands.
- Enable running commands without config file.
- Improve README, including a full configuration example.

# 0.1.0

- First release
